@@ -10,14 +10,15 @@ parentdir="$(dirname "$0")"
 # (jsoncpp, open62541, picojson). Also check libp11, dpkg, and systemd since
 # those are common dependencies not enabled by default.
 ${parentdir}/find_dependencies.py aktualizr
-${parentdir}/find_dependencies.py aktualizr-auto-prov
-${parentdir}/find_dependencies.py aktualizr-auto-prov-creds
-${parentdir}/find_dependencies.py aktualizr-ca-implicit-prov
-${parentdir}/find_dependencies.py aktualizr-ca-implicit-prov-creds
-${parentdir}/find_dependencies.py aktualizr-hsm-prov
-${parentdir}/find_dependencies.py aktualizr-hsm-prov-creds
+${parentdir}/find_dependencies.py aktualizr-shared-prov
+${parentdir}/find_dependencies.py aktualizr-shared-prov-creds
+${parentdir}/find_dependencies.py aktualizr-device-prov
+${parentdir}/find_dependencies.py aktualizr-device-prov-creds
+${parentdir}/find_dependencies.py aktualizr-device-prov-hsm
+${parentdir}/find_dependencies.py aktualizr-auto-reboot
 ${parentdir}/find_dependencies.py aktualizr-disable-send-ip
 ${parentdir}/find_dependencies.py aktualizr-log-debug
+${parentdir}/find_dependencies.py aktualizr-polling-interval
 ${parentdir}/find_dependencies.py libp11
 ${parentdir}/find_dependencies.py dpkg
 ${parentdir}/find_dependencies.py systemd
